deathbed — deathbed health report

# DEATHBED

every codebase has files that are dying. find them.

repo: C:\Users\ASUS\Desktop\Projects\deathbed · 10 files shown · 2.70s

18
🔍 scanned
0
💀 critical
0
⚠️ warning
2
🌡 fair
8
✅ healthy
0
🧟 dead code
0
🔐 sec smells

HLTH ↕ | FILE ↕ | LINES ↕ | TOUCHED ↕ | CHURN ↕ | RECENT ↕ | AUTH ↕ | CPLX ↕ | DIAGNOSIS ↕
--- | --- | --- | --- | --- | --- | --- | --- | ---
🌡 83 | deathbed/display.py | 932 | today | 1 | 1 | 1 | 5.4 | growing out of control
🌡 85 | deathbed/analyzer.py | 256 | today | 1 | 1 | 1 | 11.7 | complexity graveyard
✅ 89 | deathbed/export.py | 299 | today | 0 | 0 | 0 | 6.1 | healthy
✅ 89 | deathbed/git_utils.py | 267 | today | 1 | 1 | 1 | 7.6 | healthy
✅ 89 | deathbed/scoring.py | 286 | today | 1 | 1 | 1 | 6.4 | healthy
✅ 91 | tests/test_scoring.py | 329 | today | 0 | 0 | 0 | 2.1 | healthy
✅ 94 | deathbed/cli.py | 248 | today | 1 | 1 | 1 | 3.5 | healthy
✅ 94 | tests/test_analyzer.py | 152 | today | 0 | 0 | 0 | 2.7 | healthy
✅ 94 | tests/test_display.py | 316 | today | 0 | 0 | 0 | 1.6 | healthy
✅ 94 | tests/test_display_extra.py | 325 | today | 0 | 0 | 0 | 1.8 | healthy

🪦 MOST WANTED
deathbed/display.py
"growing out of control" — 83/100

Size | 35 | 932 lines
Age | 100 | today
Churn | 100 | 1 commits
Recent | 100 | 1 in 90d
Complexity | 55 | 5.4
Authors | 100 | 1
Tests | 100 | ✅ found
Dead Code | 100 | none

⚡ QUICK WINS
● deathbed/analyzer.py score:85 → review and improve
● deathbed/display.py score:83 → review and improve